.. image logo.png
   ..:height: 6em
   ..:align: left

=====================================
`Tweeply <http://balkian.com/tweeply>`_
=====================================
.. image https://travis-ci.org/gsi-upm/tweeply?branch=master
    ..:target: https://travis-ci.org/gsi-upm/tweeply

TO-DO
-----

* Instalation instructions
* Improve documentation and generate via Sphinx
* ReadTheDocs
* Improve README
